#
# spec file for package python3-pyasn1
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pyasn1
Version:        0.1.8
Release:        6.1
Summary:        ASN.1 types and codecs
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://pyasn1.sf.net/
Source:         http://pypi.python.org/packages/source/p/pyasn1/pyasn1-%{version}.tar.gz
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Provides:       python3-asn1 = %{version}
Obsoletes:      python3-asn1 < 0.1.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This is an implementation of ASN.1 types and codecs in Python programming
language. It has been first written to support particular protocol (SNMP) but
then generalized to be suitable for a wide range of protocols based on ASN.1
specification.

%prep
%setup -q -n pyasn1-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGES LICENSE README THANKS TODO doc
%{python3_sitelib}/pyasn1
%{python3_sitelib}/pyasn1-%{version}-py%{py3_ver}.egg-info

%changelog
* Tue Jun 30 2015 arun@gmx.de
- specfile:
  * update copyright year
  * switched to setuptools
- update to version 0.1.8:
  * ObjectIdentifier codec fixed to work properly with arc 0 and arc 2 values.
  * Explicit limit on ObjectIdentifier arc value size removed.
  * Unicode initializer support added to OctetString type and derivatives.
  * New prettyPrintType() abstract method implemented to base pyasn1 types
    to facilitate encoding errors analisys.
  * The __str__() method implemented to Tag, TagSet and TagMap classes to
    ease encoding errors troubleshooting.
    easing encoding errors
  * Fix to SEQUENCE and SET types to give them their private componentTypes
    collection (which is a NamedTypes object) so that they won't collide in
    a MT execution environment.
  * Missing T61String,ISO646String character types and ObjectDescriptor useful
    type added.
  * Distribute is gone, switched to setuptools completely.
  * Missing NamedValues.__repr__() added.
  * The base.NoValue() class, that indicates uninitialized ASN.1 object,
    made public.
  * The base.NoValue() class instances now support __repr__() what makes
    possible to perform repr() on uninitialized pyasn1 types objects.
  * When comparing ASN.1 types, by-tag and/or by-constraints matching
    can now be performed with the isSuperTypeOf()/isSameTypeWith() optional
    flags.
  * Constructed types now verify their consistency by invoking
    isSameTypeWith(matchTags=True, matchConstraints=False) and
    isSuperTypeOf(matchTags=False, matchConstraints=True) for each of their
    components rather than isSuperTypeOf() as it used to be. Constriants check
    could be enforced to isSameTypeWith() with the strictConstraints=True
    constructed classes attribute.
  * Constructed types can now be initialized with new .setComponents() method
    which accepts both var-args and keyword-args. Default repr() modified to
    reflect this change.
  * NamedTypes() and NamedValues() made comparable.
  * Test coverage extended to cover pyasn1 types __repr__() function.
  * The abs(Integer()) & abs(Real()) operation now returns respective pyasn1
    type, not a Python type.
  * More Python magic methods implementations added to Integer & Real classes
    (e.g.  __pos__, __neg__, __round__, __floor__, __ceil__, __trunc__)
  * The Integer.__invert__ Python magic method implemented.
  * The OctetString.__int__() and .__float__() magic methods implemented.
  * Handle the case of null writer at Debug printer.
  * BitString encoder/decoder performance improved.
  * Built-in debugging is now based on Python logging module.
  * Fix to NamedType.__repr__() to work properly.
  * Fixes to __repr__() implementation of many built-in ASN.1 types to take into
    account all of their initializers such as tagSet, subtypeSpec etc.
  * String typed float initializer to REAL type now supported.
  * Float typed mantissa initializer to REAL type for base 2 added.
  * Encoding bases 8 and 16 support for REAL type binary encoder added.
  * More strict CER/DER encoders added for GeneralizedTime and UTCTime types.
  * Asn1Item.hasValue() added to easily distinguish initalized ASN.1 objects
    from uninitialized ones (e.g. pure types).
  * Fix to REAL type binary decoder to handle different bases and scale factor.
  * Fix to TagSet.repr() to include [obsolete] baseTag information.
  * Fix to broken REAL type decoding handling.
  * Fix to BitString and OctetString decoders dealing with constructed
    encoding -  * it used to be possible to embed other types in substrate.
  * Fix to end-of-octest sentinel handling:
    + require strict two-zeros sentinel encoding
    + recognize EOO sentinel only when explicitly requested by caller
    of the decoder via allowEoo=True parameter (warning: API change)
  * DER codec hardened not to tolerate indefinite length encoding/decoding.
* Wed May  8 2013 michael@stroeder.com
- updated to upstrean release 0.1.7
  Revision 0.1.7
- License updated to vanilla BSD 2-Clause to ease package use
  (http://opensource.org/licenses/BSD-2-Clause).
- Test suite made discoverable by unittest/unittest2 discovery feature.
- Fix to decoder working on indefinite length substrate -- end-of-octets
  marker is now detected by both tag and value. Otherwise zero values may
  interfere with end-of-octets marker.
- Fix to decoder to fail in cases where tagFormat indicates inappropriate
  format for the type (e.g. BOOLEAN is always PRIMITIVE, SET is always
  CONSTRUCTED and OCTET STRING is either of the two)
- Fix to REAL type encoder to force primitive encoding form encoding.
- Fix to CHOICE decoder to handle explicitly tagged, indefinite length
  mode encoding
- Fix to REAL type decoder to handle negative REAL values correctly. Test
  case added.
* Wed Apr 24 2013 highwaystar.ru@gmail.com
- initial python3 package
